@@ -4,7 +4,7 @@ use Carp;
 use IO::File;
 use namespace::clean;
 
-our $VERSION; BEGIN { $VERSION= '0.000_002' }
+our $VERSION= '0.000_003';
 
 # ABSTRACT: Encode elf files with pure-perl
 
@@ -21,12 +21,14 @@ _init_enum(\%class_to_sym, \%class_from_sym,
 	'32bit' => 1,
 	'64bit' => 2,
 );
+
 has class => ( is => 'rw', coerce => sub {
 	my $x= $class_from_sym{$_[0]};
 	defined $x? $x
 		: (int($_[0]) == $_[0])? $_[0]
 		: croak "$_[0] is not a valid 'class'"
 });
+
 sub class_sym {
 	my $self= shift;
 	$self->class($_[0]) if @_;
@@ -40,12 +42,14 @@ _init_enum(\%data_to_sym, \%data_from_sym,
 	'2LSB' => 1,
 	'2MSB' => 2,
 );
+
 has data => ( is => 'rw', coerce => sub {
 	my $x= $data_from_sym{$_[0]};
 	defined $x? $x
 		: (int($_[0]) == $_[0])? $_[0]
 		: croak "$_[0] is not a valid 'data'"
 });
+
 sub data_sym {
 	my $self= shift;
 	$self->data($_[0]) if @_;
@@ -77,6 +81,7 @@ has osabi => ( is => 'rw', coerce => sub {
 		: (int($_[0]) == $_[0])? $_[0]
 		: croak "$_[0] is not a valid 'osabi'"
 });
+
 sub osabi_sym {
 	my $self= shift;
 	$self->osabi($_[0]) if @_;
@@ -95,12 +100,14 @@ _init_enum(\%type_to_sym, \%type_from_sym,
 	'shared'      => 3,
 	'core'        => 4,
 );
+
 has type => ( is => 'rw', coerce => sub {
 	my $x= $type_from_sym{$_[0]};
 	defined $x? $x
 		: (int($_[0]) == $_[0])? $_[0]
 		: croak "$_[0] is not a valid 'type'"
 });
+
 sub type_sym {
 	my $self= shift;
 	$self->type($_[0]) if @_;
@@ -125,12 +132,14 @@ _init_enum(\%machine_to_sym, \%machine_from_sym,
 	'x86-64'      => 0x3E,
 	'AArch64'     => 0xB7,
 );
+
 has machine => ( is => 'rw', coerce => sub {
 	my $x= $machine_from_sym{$_[0]};
 	defined $x? $x
 		: (int($_[0]) == $_[0])? $_[0]
 		: croak "$_[0] is not a valid 'machine'"
 });
+
 sub machine_sym {
 	my $self= shift;
 	$self->machine($_[0]) if @_;
@@ -449,7 +458,7 @@ sub _serialize_section_header {
 
 sub write_file {
 	my ($self, $filename, $mode)= @_;
-	$mode= 0555 unless defined $mode;
+	$mode= 0755 unless defined $mode;
 	require File::Temp;
 	my ($fh, $tmpname)= File::Temp::tempfile( $filename.'-XXXXXX' );
 	print $fh $self->serialize or croak "write: $!";
@@ -458,10 +467,13 @@ sub write_file {
 	rename($tmpname, $filename) or croak "rename: $!";
 }
 
+# coerce arrayref of hashrefs into arrayref of objects
 sub _coerce_segments {
 	my $spec= shift;
 	return [ map { (__PACKAGE__.'::Segment')->coerce($_) } @$spec ];
 }
+
+# coerce arrayref of hashrefs into arrayref of objects
 sub _coerce_sections {
 	my $spec= shift;
 	return [ map { (__PACKAGE__.'::Section')->coerce($_) } @$spec ];
@@ -499,6 +511,8 @@ sub _apply_section_defaults {
 		}
 	}
 }
+
+# Overridden by subclasses for machine-specific defaults
 sub _apply_segment_defaults {
 	my ($self, $seg)= @_;
 	# Undef type is "null" type 0
@@ -526,8 +540,9 @@ sub _apply_segment_defaults {
 	}
 }
 
-use ELF::Writer::Segment;
-use ELF::Writer::Section;
+# Load last so make sure data is initialized
+require ELF::Writer::Segment;
+require ELF::Writer::Section;
 
 1;
 
@@ -543,29 +558,30 @@ ELF::Writer - Encode elf files with pure-perl
 
 =head1 VERSION
 
-version 0.000_002
+version 0.000_003
 
 =head1 SYNOPSIS
 
   my $elf= ELF::Writer::Linux_x86_64->new(
     type => 'executable',
     segments => [{
-      offset      => 0, # overlap segment with elf header
       virt_addr   => 0x10000,
       data        => $my_machine_code,
-      data_start  => undef # calculated below
     }],
+    entry_point => 0x10000,
   );
+  $elf->write_file($binary_name);
   
-  # Overlap the first segment with the elf header, for size efficiency
+  # Example above wastes almost 4K to align the first segment.
+  # We can overlap the first segment with the elf header, using this trick:
   # http://www.muppetlabs.com/~breadbox/software/tiny/teensy.html
+  # Note that this moves our machine code, which can affect RIP-relative
+  # addressing.
   
   my $prog_offset= $elf->elf_header_len + $elf->segment_header_elem_len;
+  $elf->segments->[0]->offset(0);
   $elf->segments->[0]->data_start( $prog_offset );
   $elf->entry_point( $elf->segments->[0]->virt_addr + $prog_offset );
-  
-  # Write out an elf file
-  $elf->write_file($binary_name);
 
 =head1 MODULE STATUS
 
@@ -593,11 +609,11 @@ name by a second attribute accessor with suffix "_sym".
 
 =head2 class, class_sym
 
-8-bit integer, or one of: '32bit' or '64bit'.  Must be set before writing.
+8-bit integer, or one of: C<"32bit"> or C<"64bit">.  Must be set before writing.
 
 =head2 data, data_sym
 
-8-bit integer, or one of: '2LSB' or '2MSB'. (2's complement least/most
+8-bit integer, or one of: C<"2LSB"> or C<"2MSB">. (2's complement least/most
 significant byte first)  i.e. little-endian or big-endian
 
 Must be set before writing.
@@ -608,8 +624,8 @@ Must be set before writing.
 
 =head2 osabi, osabi_sym
 
-8-bit integer, or one of: 'SystemV', 'HP-UX', 'NetBSD', 'Linux', 'Solaris',
-'AIX', 'IRIX', 'FreeBSD', 'OpenBSD', 'OpenVMS'.  Must be set before writing.
+8-bit integer, or one of: C<"SystemV">, C<"HP-UX">, C<"NetBSD">, C<"Linux">, C<"Solaris",
+C<"AIX">, C<"IRIX">, C<"FreeBSD">, C<"OpenBSD">, C<"OpenVMS">.  Must be set before writing.
 
 =head2 osabi_version
 
@@ -617,22 +633,22 @@ Depends on osabi.  Not used for Linux.  Defaults to 0.
 
 =head2 type, type_sym
 
-16-bit integer, or one of: 'relocatable', 'executable', 'shared', 'core'.
+16-bit integer, or one of: C<"relocatable">, C<"executable">, C<"shared">, C<"core">.
 Must be set before writing.
 
 =head2 machine, machine_sym
 
-16-bit integer, or one of: 'Sparc', 'x86', 'MIPS', 'PowerPC', 'ARM', 'SuperH',
-'IA-64', 'x86-64', 'AArch64'.
+16-bit integer, or one of: C<"Sparc">, C<"x86">, C<"MIPS">, C<"PowerPC">, C<"ARM">, C<"SuperH">,
+C<"IA-64">, C<"x86-64">, C<"AArch64">.
 
 =head2 version
 
-32-bit integer; defaults to '1' for original version of ELF.
+32-bit integer; defaults to C<1> for original version of ELF.
 
 =head2 entry_point
 
 32-bit or 64-bit pointer to address where process starts executing.
-Defaults to 0 unless type is 'executable', then you must specify it before
+Defaults to C<0> unless type is C<"executable">, then you must specify it before
 writing.
 
 =head2 flags
@@ -658,11 +674,11 @@ the constructor which will be coerced automatically.
 
 =head2 segment_count
 
-Handy alias for $#{ $elf->segments }
+Handy alias for C<$#{ $elf->segments }>
 
 =head2 segment_list
 
-Handy alias for @{ $elf->segments }
+Handy alias for C<@{ $elf->segments }>
 
 =head2 sections
 
@@ -671,11 +687,11 @@ the constructor which will be coerced automatically.
 
 =head2 section_count
 
-Handy alias for $#{ $elf->sections }
+Handy alias for C<$#{ $elf->sections }>
 
 =head2 section_list
 
-Handy alias for @{ $elf->sections }
+Handy alias for C<@{ $elf->sections }>
 
 =head2 section_name_string_table_index
 
@@ -693,7 +709,7 @@ attributes are missing.
 
   $elf->write_file( $filename [, $mode]);
 
-Convenience method for writing to a file.  Writes with mode 0555 by default.
+Convenience method for writing to a file.  Writes with mode 0755 by default.
 
 =head1 AUTHOR
 
