@@ -1,7 +1,6 @@
 package ELF::Writer::Linux_x86_64;
 use Moo 2;
 use namespace::clean;
-
 extends 'ELF::Writer';
 
 # ABSTRACT: ELF::Writer with defaults for Linux on x86_64
@@ -33,7 +32,7 @@ ELF::Writer::Linux_x86_64 - ELF::Writer with defaults for Linux on x86_64
 
 =head1 VERSION
 
-version 0.000_002
+version 0.000_003
 
 =head1 DESCRPTION
 
@@ -46,19 +45,19 @@ when constructed:
 
 =item class
 
-'64-bit'
+C<"64-bit">
 
 =item data
 
-'little-endian'
+C<"little-endian">
 
 =item osabi
 
-'Linux'
+C<"Linux">
 
 =item machine
 
-'x86-64'
+C<"x86-64">
 
 =back
 
